import axios from "axios"
import { useState } from "react"
import { useNavigate } from "react-router-dom"

import TopBar from "../components/TopBar"

export default function Login () {
    const navigate = useNavigate()
    const [email, setEmail] = useState("")
    const [password, setPassword] = useState("")

    function handleSubmit(e: React.FormEvent<HTMLFormElement>) {
        e.preventDefault()
        if (email === "" || password === "") {
            alert("Please fill in all fields")
            return
        }
        axios
            .post("/api/auth/login", {
                email,
                password
            })
            .then((response) => {
                console.log(response.data)
                localStorage.setItem("token", response.data.token)
                navigate("/")
            })
            .catch((error) => {
                alert("Login failed : " + error.response)
            })
    }

    return (
        <div>
            <TopBar user={undefined} />
            <div className="card bg-base-200 m-4">
                <form onSubmit={handleSubmit} className="card-body gap-5 flex flex-col items-center">
                    <div className="card-title">
                        <h1>Login</h1>
                    </div>
                    <input type="text" id="username" name="username" className="input" value={email} onChange={(e) => setEmail(e.target.value)} placeholder="Email" />
                    <input type="password" id="password" name="password" className="input" value={password} onChange={(e) => setPassword(e.target.value)} placeholder="Password" />
                    <div className="card-actions">
                        <button type="submit" className="btn bg-accent" >Login</button>
                    </div>
                </form>
                
            </div>
        </div>
    )
}