import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import axios from 'axios';

import TopBar from '../components/TopBar';

export default function Register () {
    const navigate = useNavigate();
    const [name, setName] = useState<string>("");
    const [lastname, setLastname] = useState<string>("");
    const [email, setEmail] = useState<string>("");
    const [numero, setNumero] = useState<string>("");
    const [password, setPassword] = useState<string>("");

    function handleSubmit(e: React.FormEvent<HTMLFormElement>) {
        e.preventDefault();
        if (name === "" || lastname === "" || email === "" || numero === "" || password === "") {
            alert("Please fill in all fields");
            return;
        }
        axios
            .post("/api/auth/register", {
                name,
                lastname,
                email,
                numero,
                password
            })
            .then(() => {
                axios
                    .post("/api/auth/login", {
                        email,
                        password
                    })
                    .then((response) => {
                        localStorage.setItem("token", response.data.token);
                        navigate("/");
                    })
                    .catch((error) => {
                        console.error(error.response.data);
                    });
            })
            .catch((error) => {
                console.error(error.response.data);
            });
    }

    return (
        <div>
            <TopBar user={undefined} />
            <div className="card bg-base-200 m-4">
                <form onSubmit={handleSubmit} className="card-body gap-5 flex flex-col items-center">
                    <div className='card-title'>
                        <h1>Register</h1>
                    </div>
                    <input type="text" className='input' placeholder="Name" value={name} onChange={(e) => setName(e.target.value)} />
                    <input type="text" className='input' placeholder="Lastname" value={lastname} onChange={(e) => setLastname(e.target.value)} />
                    <input type="text" className='input' placeholder="Email" value={email} onChange={(e) => setEmail(e.target.value)} />
                    <input type="text" className='input' placeholder="Numero" value={numero} onChange={(e) => setNumero(e.target.value)} />
                    <input type="password" className='input' placeholder="Password" value={password} onChange={(e) => setPassword(e.target.value)} />
                    <button type="submit" className='btn bg-accent'>Register</button>
                </form>
            </div>
        </div>
    )
}